LocalUser

Struct LocalUser 

pub struct LocalUser<T> {
    pub(super) ptr: T,
}
Available on crate feature full only.

Fields

ptr: T

Implementations

Source

impl<T: ?Sized> LocalUser<*const T>

pub unsafe fn new(addr: usize) -> Self
where T: Sized,

Creates a new LocalUser<*const T> with tied to the current address space

Safety

addr, if valid, must point to a valid bit pattern for T in the current address space. This means that in almost all cases, it is unsound to create a LocalUser<*const T> where T has a niche.

For all types with no invalid bit-patterns (i.e. all numeric types) it is sound to create a LocalUser<*const T>.

pub const fn is_null(&self) -> bool

Returns true if the pointer has a null address

pub const unsafe fn offset(self, count: isize) -> Self
where T: Sized,

Adds a signed offset to a pointer.

count is in units of T; e.g., a count of 3 represents a pointer offset of 3 * size_of::<T>() bytes.

Safety

See safety requirements for [<*const T>::offset()]

pub const unsafe fn byte_offset(self, count: isize) -> Self

Adds a signed offset in bytes to a pointer.

Safety

See safety requirements for [<*const T>::byte_offset()]

pub const unsafe fn add(self, count: usize) -> Self
where T: Sized,

Adds an offset to a pointer.

count is in units of T; e.g., a count of 3 represents a pointer offset of 3 * size_of::<T>() bytes.

Safety

See safety requirements for [<*const T>::add()]

pub const unsafe fn byte_add(self, count: usize) -> Self

Adds an offset in bytes to a pointer.

Safety

See safety requirements for [<*const T>::byte_add()]

pub const unsafe fn sub(self, count: usize) -> Self
where T: Sized,

Subtracts an offset from a pointer.

count is in units of T; e.g., a count of 3 represents a pointer offset of 3 * size_of::<T>() bytes.

Safety

See safety requirements for [<*const T>::sub()]

pub const unsafe fn byte_sub(self, count: usize) -> Self

Subtracts an offset in bytes from a pointer.

Safety

See safety requirements for [<*const T>::byte_sub()]

pub fn read(self) -> Result<T, PointerError>
where T: Sized + Copy,

Tries to read the value pointed to by the pointer

Errors

If the pointer is invalid due to unmapped memory or similar, returns PointerError

pub const unsafe fn cast<U>(self) -> LocalUser<*const U>

Casts a pointer to another type

Safety

If self has a valid address, then it must point to a valid bit pattern for U in the current address space. This means that in almost all cases, it is unsound to cast to a LocalUser<*const U> where U has a niche.

For all types with no invalid bit-patterns (i.e. all numeric types) it is sound to cast to a User<*const U>.

pub const fn cast_mut(self) -> LocalUser<*mut T>

Casts to a writable pointer

pub fn is_aligned_to(self, align: usize) -> bool

pub fn addr(self) -> VirtualAddress

pub fn align_offset(self, align: usize) -> usize
where T: Sized,

Source

impl<T: ?Sized> LocalUser<*mut T>

pub fn new(addr: usize) -> Self
where T: Sized,

Creates a new LocalUser<*mut T> with the provided address tied to the current address space

pub const fn is_null(&self) -> bool

Returns true if the pointer has a null address

pub const unsafe fn offset(self, count: isize) -> Self
where T: Sized,

Adds a signed offset to a pointer.

count is in units of T; e.g., a count of 3 represents a pointer offset of 3 * size_of::<T>() bytes.

Safety

See safety requirements for [<*mut T>::offset()]

pub const unsafe fn byte_offset(self, count: isize) -> Self

Adds a signed offset in bytes to a pointer.

Safety

See safety requirements for [<*mut T>::byte_offset()]

pub const unsafe fn add(self, count: usize) -> Self
where T: Sized,

Adds an offset to a pointer.

count is in units of T; e.g., a count of 3 represents a pointer offset of 3 * size_of::<T>() bytes.

Safety

See safety requirements for [<*mut T>::add()]

pub const unsafe fn byte_add(self, count: usize) -> Self

Adds an offset in bytes to a pointer.

Safety

See safety requirements for [<*mut T>::byte_add()]

pub const unsafe fn sub(self, count: usize) -> Self
where T: Sized,

Subtracts an offset from a pointer.

count is in units of T; e.g., a count of 3 represents a pointer offset of 3 * size_of::<T>() bytes.

Safety

See safety requirements for [<*mut T>::sub()]

pub const unsafe fn byte_sub(self, count: usize) -> Self

Subtracts an offset in bytes from a pointer.

Safety

See safety requirements for [<*mut T>::byte_sub()]

pub fn write(self, value: T) -> Result<(), PointerError>
where T: Sized,

Tries to write to the value pointed to by the pointer

Errors

If the pointer is invalid due to unmapped memory or similar, returns PointerError

pub const fn cast<U>(self) -> LocalUser<*mut U>

Casts a pointer to another type

pub const unsafe fn cast_const(self) -> LocalUser<*const T>

Casts to a readable pointer

Safety

addr, if valid, must point to a valid bit pattern for T in the current address space. This means that in almost all cases, it is unsound to cast to a LocalUser<*const T> where T has a niche.

For all types with no invalid bit-patterns (i.e. all numeric types) it is sound to cast to a LocalUser<*const T>.

pub fn is_aligned_to(self, align: usize) -> bool

pub fn addr(self) -> VirtualAddress

pub fn align_offset(self, align: usize) -> usize
where T: Sized,

Source

impl<T> LocalUser<*const [T]>

pub const fn len(self) -> usize

pub const fn is_empty(self) -> bool

pub const fn as_ptr(self) -> LocalUser<*const T>

pub fn read_to_box(self) -> Result<Box<[T]>, PointerError>

pub fn read_to_buffer( self, buffer: &mut [MaybeUninit<T>], ) -> Result<usize, PointerError>

Source

impl<T> LocalUser<*mut [T]>

pub const fn len(self) -> usize

pub const fn is_empty(self) -> bool

pub const fn as_mut_ptr(self) -> LocalUser<*mut T>

pub fn write_from_slice(self, slice: &[T]) -> Result<usize, PointerError>